@@ -1,4 +1,4 @@
-#' Media agrupada usando diseño complejo
+#' Media agrupada usando disenio complejo
 #' @description Usa los factores de expansion, conglomerados y estratos para
 #' calcular correctamente las medias comunales o regionales.
 #' @param disenio la salida de `configuracion_disenio()` que provee ademas los
@@ -9,14 +9,10 @@
 #' media_agrupada(cd)
 #' @export
 media_agrupada <- function(disenio) {
-  estimate <- mean_median(d_groups = disenio$grupos,
-                          des = disenio$disenio,
+  estimate <- mean_median(disenio$grupos, disenio$disenio,
                           stat_fun = srvyr::survey_mean,
-                          agrupacion = disenio$agrupacion,
-                          conglomerado = disenio$conglomerado,
-                          estrato = disenio$estrato,
-                          peso = disenio$peso,
-                          variable = disenio$variable,
+                          disenio$agrupacion, disenio$conglomerado,
+                          disenio$estrato, disenio$peso, disenio$variable,
                           col_prefix = "media_")
   names(estimate) <- gsub("_low", "_inf", names(estimate))
   names(estimate) <- gsub("_upp", "_sup", names(estimate))
@@ -24,7 +20,7 @@ media_agrupada <- function(disenio) {
   return(estimate)
 }
 
-#' Mediana agrupada usando diseño complejo
+#' Mediana agrupada usando disenio complejo
 #' @description Usa los factores de expansion, conglomerados y estratos para
 #' calcular correctamente las medianas comunales o regionales.
 #' @param disenio la salida de `configuracion_disenio()` que provee ademas los
@@ -46,7 +42,7 @@ mediana_agrupada <- function(disenio) {
   return(estimate)
 }
 
-#' Percentiles agrupados usando diseño complejo
+#' Percentiles agrupados usando disenio complejo
 #' @description Usa los factores de expansion, conglomerados y estratos para
 #' calcular correctamente los percentiles comunales o regionales.
 #' @param disenio la salida de `configuracion_disenio()` que provee ademas los
